summaryrefslogtreecommitdiff
path: root/gcc/attribs.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/attribs.c')
-rw-r--r--gcc/attribs.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/gcc/attribs.c b/gcc/attribs.c
index ba6a9e294c8..dbce1815e68 100644
--- a/gcc/attribs.c
+++ b/gcc/attribs.c
@@ -252,18 +252,18 @@ decl_attributes (tree *node, tree attributes, int flags)
&& !DECL_FUNCTION_SPECIFIC_OPTIMIZATION (*node))
DECL_FUNCTION_SPECIFIC_OPTIMIZATION (*node) = optimization_current_node;
- /* If this is a function and the user used #pragma GCC option, add the
- options to the attribute((option(...))) list. */
+ /* If this is a function and the user used #pragma GCC target, add the
+ options to the attribute((target(...))) list. */
if (TREE_CODE (*node) == FUNCTION_DECL
- && current_option_pragma
+ && current_target_pragma
&& targetm.target_option.valid_attribute_p (*node, NULL_TREE,
- current_option_pragma, 0))
+ current_target_pragma, 0))
{
- tree cur_attr = lookup_attribute ("option", attributes);
- tree opts = copy_list (current_option_pragma);
+ tree cur_attr = lookup_attribute ("target", attributes);
+ tree opts = copy_list (current_target_pragma);
if (! cur_attr)
- attributes = tree_cons (get_identifier ("option"), opts, attributes);
+ attributes = tree_cons (get_identifier ("target"), opts, attributes);
else
TREE_VALUE (cur_attr) = chainon (opts, TREE_VALUE (cur_attr));
}